@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
-from ._compat import to_unicode, iteritems
-from markupsafe import Markup, escape_silent
 import re
 from xml.sax.saxutils import quoteattr
 
+from markupsafe import Markup, escape_silent
+from ._compat import to_unicode, iteritems
+
 
 class FakeMultiDict(dict):
+
     """Adds a fake `getlist` method to a regular dict; or acts as a proxy to
     Webob's MultiDict `getall` method.
     """
@@ -64,7 +66,7 @@ def get_html_attrs(kwargs=None):
             if value is True:
                 props.append(key)
         else:
-            value = quoteattr(escape(value))
+            value = quoteattr(Markup(value))
             attrs.append(u'%s=%s' % (key, value))
 
     attrs.sort()
